@@ -1,5 +1,3 @@
-"""Lookup class."""
-
 import logging
 from copy import copy
 from typing import Dict, Optional, Type
@@ -14,10 +12,16 @@ logger = logging.getLogger(__name__)
 
 
 class Lookup:
+    """Lookup class. YAML input is in this form:
+    https://github.com/OCHA-DAP/hdx-python-scraper/blob/main/src/hdx/scraper/framework/utilities/sector_configuration.yaml
+
+    Args:
+        yaml_config_path (str): YAML configuration file
+        classobject (Type): Child class
+    """
+
     def __init__(self, yaml_config_path: str, classobject: Type):
-        configuration = load_yaml(
-            script_dir_plus_file(yaml_config_path, classobject)
-        )
+        configuration = load_yaml(script_dir_plus_file(yaml_config_path, classobject))
         self._configuration = configuration
         initial_lookup = configuration.get("initial_lookup", {})
         self._code_lookup = copy(initial_lookup)
@@ -26,6 +30,16 @@ class Lookup:
         self.setup()
 
     def add_to_lookup(self, code: str, name: str) -> None:
+        """Add code and name to lookup
+
+        Args:
+            code (str): Code to add to lookup
+            name (str): Name to add to lookup
+
+        Returns:
+            None
+        """
+
         self._code_lookup[name] = code
         self._code_lookup[code] = code
         self._code_lookup[normalise(name)] = code
@@ -33,6 +47,12 @@ class Lookup:
         self._code_to_name[code] = name
 
     def setup(self) -> None:
+        """Setup lookup from YAML configuration
+
+        Returns:
+            None
+        """
+
         log_message = self._configuration["log_message"]
         logger.info(f"Populating {log_message}")
 
@@ -54,16 +74,39 @@ class Lookup:
             self.add_to_lookup(code=code, name=name)
 
     def get_code(self, code: str) -> Optional[str]:
+        """Get code from lookup using fuzzy matching if needed
+
+        Args:
+            code (str): Code to get from lookup
+
+        Returns:
+            Optional[str]: Code obtained from lookup or None if no code is found
+        """
+
         return get_code_from_name(
             name=code,
             code_lookup=self._code_lookup,
             unmatched=self._unmatched,
         )
 
-    def get_name(
-        self, code: str, default: Optional[str] = None
-    ) -> Optional[str]:
+    def get_name(self, code: str, default: Optional[str] = None) -> Optional[str]:
+        """Get name from code
+
+        Args:
+            code (str): Code to lookup
+            default (Optional[str]): Default name to return if code is not found
+
+        Returns:
+            Optional[str]: Name obtained from lookup or default if no name is found
+        """
+
         return self._code_to_name.get(code, default)
 
     def get_code_to_name(self) -> Dict[str, str]:
+        """Get the code to name lookup dictionary
+
+        Returns:
+            Dict[str, str]: Code to name lookup dictionary
+        """
+
         return self._code_to_name
